Learn R Programming

HDiR (version 1.1.3)

trapezoidal.rule: Trapezoidal rule for numerical integration over a threshold

Description

This functions implements the trapezoidal rule for numerical integration of a function \(f\) over a threshold.

Usage

trapezoidal.rule(f, step, y)

Value

A numeric value of the integral.

Arguments

f

Function to be integrated.

step

Numeric value of the distance between points for integration.

y

Numeric value of the threshold.

Author

Paula Saavedra-Nieves and Rosa M. Crujeiras.