This function calculates the Von Mises-Fisher kernel density estimator is a slight modification of function vmf.kerncontour
in Directional package. In this new version, it is possible to provide a numerical value for the bandwidth.
vmf.kerncontour2(u, h, full = FALSE, ngrid = 100)A list with kernel density estimation. For more details, see function vmf.kerncontour in Directional package.
A two column matrix. The first column is the latitude and the second is the longitude.
Numeric value for bandwidth ot smoothing parameter.
If FALSE (default), uses the range of positions from u to calculate and optionally plot densities. If TRUE, calculates densities covering the entire sphere.
Sets the resolution of the density calculation.
Paula Saavedra-Nieves and Rosa M. Crujeiras.