runif_on_sphere: Random generation of a sample on a d-dimensional sphere of radius r
Description
This function generates a random sample on the unit sphere.
Usage
runif_on_sphere(n, d, r = 1)
Value
A matrix of n rows and d columns containing the sample points.
Arguments
- n
Size of the sample to be generated.
- d
Dimension of the space which contains the sphere.
- r
Radius of the sphere.
Author
Paula Saavedra-Nieves and Rosa M. Crujeiras.